@@ -164,15 +164,6 @@ imageinfo_set_full_name (ImageInfo  *ii_info,
     ii_info->s_full_path = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get the full file name string (path + file name)
- */
-const char *
-imageinfo_get_full_name (const ImageInfo *ii_info)
-{
-     return (const char*) ii_info->s_full_path;       
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set the file name string
  */
@@ -186,15 +177,6 @@ imageinfo_set_file_name (ImageInfo  *ii_info,
     ii_info->s_file_name = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get the file name string
- */
-const char *
-imageinfo_get_file_name (const ImageInfo *ii_info)
-{
-     return (const char*) ii_info->s_file_name;       
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set the file path string
  */
@@ -208,53 +190,6 @@ imageinfo_set_file_path (ImageInfo  *ii_info,
     ii_info->s_file_path = strdup (s_name);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get the file path string
- */
-const char *
-imageinfo_get_file_path (const ImageInfo *ii_info)
-{
-     return (const char*) ii_info->s_file_path;       
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Set image width information
- */
-void
-imageinfo_set_width (ImageInfo *ii_info, 
-                     const int  i_val)
-{
-    ii_info->i_width = i_val; 
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Get image width value
- */
-int
-imageinfo_get_width (const ImageInfo *ii_info)
-{
-    return ii_info->i_width;
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Set image height information
- */
-void
-imageinfo_set_height (ImageInfo *ii_info, 
-                      const int  i_val)
-{
-    ii_info->i_height = i_val; 
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Get image height value
- */
-int
-imageinfo_get_height (const ImageInfo *ii_info)
-{
-    return ii_info->i_height;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get string with image dimensions (width x height)
  */
@@ -274,13 +209,4 @@ imageinfo_set_wxh (ImageInfo *ii_info,
     ii_info->s_width_height[n] = '\0';
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get string with image dimensions (width x height)
- */
-const char *
-imageinfo_get_wxh (const ImageInfo *ii_info)
-{
-    return (const char*) ii_info->s_width_height;
-}
-/*----------------------------------------------------------------------------*/
 
